@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -21,8 +21,6 @@
 #define ABSTRACTTEXTTOSPEECHINTERFACE_H
 #include "kpimtextedit_export.h"
 #include <QObject>
-#include <QVector>
-#include <QLocale>
 namespace KPIMTextEdit {
 class KPIMTEXTEDIT_EXPORT AbstractTextToSpeechInterface : public QObject
 {
